@@ -14,7 +14,7 @@ app = Flask(__name__)
 @app.route('/')
 def index():
     pm = ProxyManager()
-    return 'done'
+    return pm.value()
 
 
 def run():
